You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2020/09/16 04:13:46 UTC

[camel] branch master updated: Document Change (#4235)

This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/master by this push:
     new 8c18317  Document Change (#4235)
8c18317 is described below

commit 8c18317e571c1c8d5aba6b8064d9216545b9ed77
Author: Nitesh Koushik S <39...@users.noreply.github.com>
AuthorDate: Wed Sep 16 09:43:21 2020 +0530

    Document Change (#4235)
    
    Change in keyword from "Possibles" to "Possible"
---
 .../main/java/org/apache/camel/component/jms/JmsConfiguration.java    | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsConfiguration.java b/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsConfiguration.java
index ec623d5..ee8bd6d 100644
--- a/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsConfiguration.java
+++ b/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsConfiguration.java
@@ -219,7 +219,7 @@ public class JmsConfiguration implements Cloneable {
     private boolean deliveryPersistent = true;
     @UriParam(enums = "1,2", label = "producer",
               description = "Specifies the delivery mode to be used."
-                            + " Possibles values are those defined by javax.jms.DeliveryMode."
+                            + " Possible values are those defined by javax.jms.DeliveryMode."
                             + " NON_PERSISTENT = 1 and PERSISTENT = 2.")
     private Integer deliveryMode;
     @UriParam(defaultValue = "true", label = "consumer",
@@ -1295,7 +1295,7 @@ public class JmsConfiguration implements Cloneable {
     }
 
     /**
      * Specifies the delivery mode to be used. Possibles values are those defined by javax.jms.DeliveryMode.
      * NON_PERSISTENT = 1 and PERSISTENT = 2.
      */
     public void setDeliveryMode(Integer deliveryMode) {
@@ -1295,7 +1295,7 @@ public class JmsConfiguration implements Cloneable {
 
     /**
-     * Specifies the delivery mode to be used. Possibles values are those defined by javax.jms.DeliveryMode.
+     * Specifies the delivery mode to be used. Possible values are those defined by javax.jms.DeliveryMode.
      * NON_PERSISTENT = 1 and PERSISTENT = 2.
      */